==> OOo_3.0.1_src_extensions.tar.bz2: core/source/org/jfree/report/util/beans/ClassValueConverter.java <==
/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://reporting.pentaho.org/
 *
 * (C) Copyright 2000-2007, by Object Refinery Limited, Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * $Id: ClassValueConverter.java 2725 2007-04-01 18:49:29Z taqua $
 * ------------
 * (C) Copyright 2000-2005, by Object Refinery Limited.
 * (C) Copyright 2005-2007, by Pentaho Corporation.
 */
package org.jfree.report.util.beans;

import org.jfree.util.ObjectUtilities;

/**
 * A class that handles the conversion of {@link Integer} attributes to and from their
 * {@link String} representation.
 *
 * @author Thomas Morgner
 */
public class ClassValueConverter implements ValueConverter
{
  public ClassValueConverter ()
  {
  }

  public String toAttributeValue (final Object o)
  {
    if (o instanceof Class)
    {
      final Class c = (Class) o;
      return c.getName();
    }
    throw new ClassCastException("Give me a real type.");
  }

  public Object toPropertyValue (final String s)
  {
    try
    {
      final ClassLoader loader = ObjectUtilities.getClassLoader(ClassValueConverter.class);
      return loader.loadClass(s);
    }
    catch (ClassNotFoundException e)
    {
      throw new IllegalArgumentException("No such class.");
    }
  }
}

==> OOo_3.2.0_src_extensions.tar.bz2: core/source/org/jfree/report/util/beans/ClassValueConverter.java <==
/**
 * ========================================
 * JFreeReport : a free Java report library
 * ========================================
 *
 * Project Info:  http://reporting.pentaho.org/
 *
 * (C) Copyright 2000-2007, by Object Refinery Limited, Pentaho Corporation and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 *
 * ------------
 * $Id: ClassValueConverter.java 6659 2008-12-02 15:35:06Z tmorgner $
 * ------------
 * (C) Copyright 2000-2005, by Object Refinery Limited.
 * (C) Copyright 2005-2007, by Pentaho Corporation.
 */
package org.jfree.report.util.beans;

import org.pentaho.reporting.libraries.base.util.ObjectUtilities;


/**
 * A class that handles the conversion of {@link Integer} attributes to and from their
 * {@link String} representation.
 *
 * @author Thomas Morgner
 */
public class ClassValueConverter implements ValueConverter
{
  public ClassValueConverter ()
  {
  }

  public String toAttributeValue (final Object o)
  {
    if (o instanceof Class)
    {
      final Class c = (Class) o;
      return c.getName();
    }
    throw new ClassCastException("Give me a real type.");
  }

  public Object toPropertyValue (final String s)
  {
    try
    {
      final ClassLoader loader = ObjectUtilities.getClassLoader(ClassValueConverter.class);
      return loader.loadClass(s);
    }
    catch (ClassNotFoundException e)
    {
      throw new IllegalArgumentException("No such class.");
    }
  }
}
